==> gnash-0.8.0.tar.bz2: gnash-0.8.0/libbase/sharedlib.h <==
// 
//   Copyright (C) 2005, 2006, 2007 Free Software Foundation, Inc.
// 
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

#ifndef __SHAREDLIB_H__
#define __SHAREDLIB_H__

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <string>
#include <map>
#include <ltdl.h>
#include "as_object.h"

// Used on Darwin for basename
#ifdef HAVE_LIBGEN_H
#include <libgen.h>
#endif

namespace gnash 
{
  

/// TODO: document this class
class SharedLib
{
public:
    // Typedefs for function pointers to keep the code readable
    typedef bool entrypoint (void *obj);
    typedef void initentry (as_object &obj);
    
    SharedLib();
    SharedLib(const char *filespec);
    ~SharedLib();
    bool openLib();
    bool openLib(std::string &filespec);
    bool openLib(const char *filespec);
    bool closeLib();
    
    // Get a C symbol from the shared library based on the name
    entrypoint *getDllSymbol (std::string &name);
    entrypoint *getDllSymbol (const char *name);
    initentry *getInitEntry (const char *name);

    // Extract file info from the shared library
    const char *getDllFileName();
    const char *getDllModuleName();
    int getDllRefCount();
    const char *moduleName();
//    lt_dlhandle getDllHandle { return _dlhandle; }
    const char *getFilespec() { return _filespec; };
    
    
private:
    lt_dlhandle _dlhandle;
    const char *_filespec;
    const char *_pluginsdir;    
};

} // end of gnash namespace

// __SHAREDLIB_H__
#endif

// Local Variables:
// mode: C++
// indent-tabs-mode: t
// End:

==> gnash-0.8.4.tar.bz2: gnash-0.8.4/libbase/sharedlib.h <==
// 
//   Copyright (C) 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
// 
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

#ifndef GNASH_SHAREDLIB_H
#define GNASH_SHAREDLIB_H

#ifdef HAVE_CONFIG_H
#include "gnashconfig.h"
#endif

#include <boost/thread/mutex.hpp>
#include <string>
#include <map>
#include "as_object.h"

#ifdef _WIN32
#undef DLL_EXPORT
#define LIBLTDL_DLL_IMPORT 1
#endif

#include <ltdl.h>

// Used on Darwin for basename
#ifdef HAVE_LIBGEN_H
#include <libgen.h>
#endif

namespace gnash 
{
  

/// TODO: document this class
class SharedLib
{
    typedef boost::mutex::scoped_lock scoped_lock;

public:
    // Typedefs for function pointers to keep the code readable
    typedef bool entrypoint (void *obj);
    typedef void initentry (as_object &obj);
    
    SharedLib();
    SharedLib(const std::string& filespec);
    ~SharedLib();

    bool openLib();
    bool openLib(const std::string &filespec);
    
    // Get a C symbol from the shared library based on the name
    entrypoint *getDllSymbol (const std::string& symbol);
    initentry *getInitEntry (const std::string& symbol);
    
private:

    bool closeLib();

    lt_dlhandle _dlhandle;
    std::string _filespec;
    boost::mutex _libMutex;    
};

} // end of gnash namespace

// GNASH_SHAREDLIB_H
#endif

// Local Variables:
// mode: C++
// indent-tabs-mode: t
// End:
